@@ -191,6 +191,8 @@ class PackagesBundle:
             for name in (
                     'NEWS',
                     'bug-presubj',
+                    'install',
+                    'links',
                     'lintian-overrides',
                     'maintscript',
                     'postinst',
@@ -204,7 +206,11 @@ class PackagesBundle:
                 except KeyError:
                     pass
                 else:
-                    with self.open(f'{package_name}.{name}') as f:
+                    if arch:
+                        out = f'{package_name}.{name}.{arch}'
+                    else:
+                        out = f'{package_name}.{name}'
+                    with self.open(out) as f:
                         f.write(template)
 
         return ret
@@ -343,8 +349,7 @@ class PackagesBundle:
                 for item in group:
                     if package.architecture != arch_all and not item.arches:
                         item.arches = package.architecture
-                    if package.build_profiles and not item.restrictions:
-                        item.restrictions = package.build_profiles
+                    item.restrictions &= package.build_profiles
                 build_dep.merge(group)
 
     def write(self) -> None:
